# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ServicePrincipalRoleArgs', 'ServicePrincipalRole']

@pulumi.input_type
class ServicePrincipalRoleArgs:
    def __init__(__self__, *,
                 role: pulumi.Input[_builtins.str],
                 service_principal_id: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a ServicePrincipalRole resource.
        :param pulumi.Input[_builtins.str] role: This is the role name, role id, or instance profile resource.
        :param pulumi.Input[_builtins.str] service_principal_id: This is the id of the service principal resource.
        """
        pulumi.set(__self__, "role", role)
        pulumi.set(__self__, "service_principal_id", service_principal_id)

    @_builtins.property
    @pulumi.getter
    def role(self) -> pulumi.Input[_builtins.str]:
        """
        This is the role name, role id, or instance profile resource.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "role", value)

    @_builtins.property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> pulumi.Input[_builtins.str]:
        """
        This is the id of the service principal resource.
        """
        return pulumi.get(self, "service_principal_id")

    @service_principal_id.setter
    def service_principal_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "service_principal_id", value)


@pulumi.input_type
class _ServicePrincipalRoleState:
    def __init__(__self__, *,
                 role: Optional[pulumi.Input[_builtins.str]] = None,
                 service_principal_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ServicePrincipalRole resources.
        :param pulumi.Input[_builtins.str] role: This is the role name, role id, or instance profile resource.
        :param pulumi.Input[_builtins.str] service_principal_id: This is the id of the service principal resource.
        """
        if role is not None:
            pulumi.set(__self__, "role", role)
        if service_principal_id is not None:
            pulumi.set(__self__, "service_principal_id", service_principal_id)

    @_builtins.property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        This is the role name, role id, or instance profile resource.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "role", value)

    @_builtins.property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        This is the id of the service principal resource.
        """
        return pulumi.get(self, "service_principal_id")

    @service_principal_id.setter
    def service_principal_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_principal_id", value)


@pulumi.type_token("databricks:index/servicePrincipalRole:ServicePrincipalRole")
class ServicePrincipalRole(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 role: Optional[pulumi.Input[_builtins.str]] = None,
                 service_principal_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        This resource allows you to attach a role or InstanceProfile (AWS) to a databricks_service_principal.

        > This resource can be used with an account or workspace-level provider.

        ## Example Usage

        Granting a service principal access to an instance profile

        ```python
        import pulumi
        import pulumi_databricks as databricks

        instance_profile = databricks.InstanceProfile("instance_profile", instance_profile_arn="my_instance_profile_arn")
        this = databricks.ServicePrincipal("this", display_name="My Service Principal")
        my_service_principal_instance_profile = databricks.ServicePrincipalRole("my_service_principal_instance_profile",
            service_principal_id=this.id,
            role=instance_profile.id)
        ```

        Granting a service principal the Account Admin role.

        > This can only be used with an account-level provider.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        tf_admin = databricks.ServicePrincipal("tf_admin", display_name="Pulumi Admin")
        tf_admin_account = databricks.ServicePrincipalRole("tf_admin_account",
            service_principal_id=tf_admin.id,
            role="account_admin")
        ```

        ## Related Resources

        The following resources are often used in the same context:

        * End to end workspace management guide.
        * UserRole to attach role or InstanceProfile (AWS) to databricks_user.
        * GroupInstanceProfile to attach InstanceProfile (AWS) to databricks_group.
        * GroupMember to attach users and groups as group members.
        * InstanceProfile to manage AWS EC2 instance profiles that users can launch Cluster and access data, like databricks_mount.
        * AccessControlRuleSet to attach other roles to account level resources.

        ## Import

        !> Importing this resource is not currently supported.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] role: This is the role name, role id, or instance profile resource.
        :param pulumi.Input[_builtins.str] service_principal_id: This is the id of the service principal resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ServicePrincipalRoleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to attach a role or InstanceProfile (AWS) to a databricks_service_principal.

        > This resource can be used with an account or workspace-level provider.

        ## Example Usage

        Granting a service principal access to an instance profile

        ```python
        import pulumi
        import pulumi_databricks as databricks

        instance_profile = databricks.InstanceProfile("instance_profile", instance_profile_arn="my_instance_profile_arn")
        this = databricks.ServicePrincipal("this", display_name="My Service Principal")
        my_service_principal_instance_profile = databricks.ServicePrincipalRole("my_service_principal_instance_profile",
            service_principal_id=this.id,
            role=instance_profile.id)
        ```

        Granting a service principal the Account Admin role.

        > This can only be used with an account-level provider.

        ```python
        import pulumi
        import pulumi_databricks as databricks

        tf_admin = databricks.ServicePrincipal("tf_admin", display_name="Pulumi Admin")
        tf_admin_account = databricks.ServicePrincipalRole("tf_admin_account",
            service_principal_id=tf_admin.id,
            role="account_admin")
        ```

        ## Related Resources

        The following resources are often used in the same context:

        * End to end workspace management guide.
        * UserRole to attach role or InstanceProfile (AWS) to databricks_user.
        * GroupInstanceProfile to attach InstanceProfile (AWS) to databricks_group.
        * GroupMember to attach users and groups as group members.
        * InstanceProfile to manage AWS EC2 instance profiles that users can launch Cluster and access data, like databricks_mount.
        * AccessControlRuleSet to attach other roles to account level resources.

        ## Import

        !> Importing this resource is not currently supported.

        :param str resource_name: The name of the resource.
        :param ServicePrincipalRoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServicePrincipalRoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 role: Optional[pulumi.Input[_builtins.str]] = None,
                 service_principal_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServicePrincipalRoleArgs.__new__(ServicePrincipalRoleArgs)

            if role is None and not opts.urn:
                raise TypeError("Missing required property 'role'")
            __props__.__dict__["role"] = role
            if service_principal_id is None and not opts.urn:
                raise TypeError("Missing required property 'service_principal_id'")
            __props__.__dict__["service_principal_id"] = service_principal_id
        super(ServicePrincipalRole, __self__).__init__(
            'databricks:index/servicePrincipalRole:ServicePrincipalRole',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            role: Optional[pulumi.Input[_builtins.str]] = None,
            service_principal_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'ServicePrincipalRole':
        """
        Get an existing ServicePrincipalRole resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] role: This is the role name, role id, or instance profile resource.
        :param pulumi.Input[_builtins.str] service_principal_id: This is the id of the service principal resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServicePrincipalRoleState.__new__(_ServicePrincipalRoleState)

        __props__.__dict__["role"] = role
        __props__.__dict__["service_principal_id"] = service_principal_id
        return ServicePrincipalRole(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def role(self) -> pulumi.Output[_builtins.str]:
        """
        This is the role name, role id, or instance profile resource.
        """
        return pulumi.get(self, "role")

    @_builtins.property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> pulumi.Output[_builtins.str]:
        """
        This is the id of the service principal resource.
        """
        return pulumi.get(self, "service_principal_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetUsersResult',
    'AwaitableGetUsersResult',
    'get_users',
    'get_users_output',
]

@pulumi.output_type
class GetUsersResult:
    """
    A collection of values returned by getUsers.
    """
    def __init__(__self__, extra_attributes=None, filter=None, id=None, users=None):
        if extra_attributes and not isinstance(extra_attributes, str):
            raise TypeError("Expected argument 'extra_attributes' to be a str")
        pulumi.set(__self__, "extra_attributes", extra_attributes)
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @_builtins.property
    @pulumi.getter(name="extraAttributes")
    def extra_attributes(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "extra_attributes")

    @_builtins.property
    @pulumi.getter
    def filter(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "filter")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def users(self) -> Sequence['outputs.GetUsersUserResult']:
        """
        A list of users matching the specified criteria. Each user has the following attributes:
        """
        return pulumi.get(self, "users")


class AwaitableGetUsersResult(GetUsersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUsersResult(
            extra_attributes=self.extra_attributes,
            filter=self.filter,
            id=self.id,
            users=self.users)


def get_users(extra_attributes: Optional[_builtins.str] = None,
              filter: Optional[_builtins.str] = None,
              users: Optional[Sequence[Union['GetUsersUserArgs', 'GetUsersUserArgsDict']]] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetUsersResult:
    """
    Retrieves information about multiple User resources.

    > This data source works with both the account-level and workspace-level provider.

    ## Example Usage

    Adding a subset of users to a group

    ```python
    import pulumi
    import pulumi_databricks as databricks

    company_users = databricks.get_users(filter="userName co \\"@domain.org\\"")
    data_users_group = databricks.Group("data_users_group", display_name="Data Users")
    add_users_to_group = []
    for range in [{"key": k, "value": v} for [k, v] in enumerate({user.id: user for user in company_users.users})]:
        add_users_to_group.append(databricks.GroupMember(f"add_users_to_group-{range['key']}",
            group_id=data_users_group.id,
            member_id=%!v(PANIC=Format method: runtime error: index out of range [-1])))
    ```

    ## Related Resources

    The following resources are used in the same context:

    - **databricks_user**: Resource to manage individual users in Databricks.
    - **databricks_group**: Resource to manage groups in Databricks.
    - **databricks_group_member**: Resource to manage group memberships by adding users to groups.
    - **databricks_permissions**: Resource to manage access control in the Databricks workspace.
    - **databricks_current_user**: Data source to retrieve information about the user or service principal that is calling the Databricks REST API.


    :param _builtins.str extra_attributes: A comma-separated list of additional user attributes to include in the results. By default, the data source returns the following attributes: `id`, `userName`, `displayName`, and `externalId`. Use this argument to request additional attributes as needed. The list of all available attributes can be found in the [API reference](https://docs.databricks.com/api/workspace/users/list).
    :param _builtins.str filter: Query by which the results have to be filtered. If not specified, all users will be returned. Supported operators are equals (`eq`), contains (`co`), starts with (`sw`), and not equals (`ne`). Additionally, simple expressions can be formed using logical operators `and` and `or`.
           
           **Examples:**
           - User whose `displayName` equals "john":
    :param Sequence[Union['GetUsersUserArgs', 'GetUsersUserArgsDict']] users: A list of users matching the specified criteria. Each user has the following attributes:
    """
    __args__ = dict()
    __args__['extraAttributes'] = extra_attributes
    __args__['filter'] = filter
    __args__['users'] = users
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getUsers:getUsers', __args__, opts=opts, typ=GetUsersResult).value

    return AwaitableGetUsersResult(
        extra_attributes=pulumi.get(__ret__, 'extra_attributes'),
        filter=pulumi.get(__ret__, 'filter'),
        id=pulumi.get(__ret__, 'id'),
        users=pulumi.get(__ret__, 'users'))
def get_users_output(extra_attributes: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     filter: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     users: Optional[pulumi.Input[Optional[Sequence[Union['GetUsersUserArgs', 'GetUsersUserArgsDict']]]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetUsersResult]:
    """
    Retrieves information about multiple User resources.

    > This data source works with both the account-level and workspace-level provider.

    ## Example Usage

    Adding a subset of users to a group

    ```python
    import pulumi
    import pulumi_databricks as databricks

    company_users = databricks.get_users(filter="userName co \\"@domain.org\\"")
    data_users_group = databricks.Group("data_users_group", display_name="Data Users")
    add_users_to_group = []
    for range in [{"key": k, "value": v} for [k, v] in enumerate({user.id: user for user in company_users.users})]:
        add_users_to_group.append(databricks.GroupMember(f"add_users_to_group-{range['key']}",
            group_id=data_users_group.id,
            member_id=%!v(PANIC=Format method: runtime error: index out of range [-1])))
    ```

    ## Related Resources

    The following resources are used in the same context:

    - **databricks_user**: Resource to manage individual users in Databricks.
    - **databricks_group**: Resource to manage groups in Databricks.
    - **databricks_group_member**: Resource to manage group memberships by adding users to groups.
    - **databricks_permissions**: Resource to manage access control in the Databricks workspace.
    - **databricks_current_user**: Data source to retrieve information about the user or service principal that is calling the Databricks REST API.


    :param _builtins.str extra_attributes: A comma-separated list of additional user attributes to include in the results. By default, the data source returns the following attributes: `id`, `userName`, `displayName`, and `externalId`. Use this argument to request additional attributes as needed. The list of all available attributes can be found in the [API reference](https://docs.databricks.com/api/workspace/users/list).
    :param _builtins.str filter: Query by which the results have to be filtered. If not specified, all users will be returned. Supported operators are equals (`eq`), contains (`co`), starts with (`sw`), and not equals (`ne`). Additionally, simple expressions can be formed using logical operators `and` and `or`.
           
           **Examples:**
           - User whose `displayName` equals "john":
    :param Sequence[Union['GetUsersUserArgs', 'GetUsersUserArgsDict']] users: A list of users matching the specified criteria. Each user has the following attributes:
    """
    __args__ = dict()
    __args__['extraAttributes'] = extra_attributes
    __args__['filter'] = filter
    __args__['users'] = users
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getUsers:getUsers', __args__, opts=opts, typ=GetUsersResult)
    return __ret__.apply(lambda __response__: GetUsersResult(
        extra_attributes=pulumi.get(__response__, 'extra_attributes'),
        filter=pulumi.get(__response__, 'filter'),
        id=pulumi.get(__response__, 'id'),
        users=pulumi.get(__response__, 'users')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['MaterializedFeaturesFeatureTagArgs', 'MaterializedFeaturesFeatureTag']

@pulumi.input_type
class MaterializedFeaturesFeatureTagArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[_builtins.str],
                 value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a MaterializedFeaturesFeatureTag resource.
        """
        pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)


@pulumi.input_type
class _MaterializedFeaturesFeatureTagState:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering MaterializedFeaturesFeatureTag resources.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)


@pulumi.type_token("databricks:index/materializedFeaturesFeatureTag:MaterializedFeaturesFeatureTag")
class MaterializedFeaturesFeatureTag(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "key"

          to = databricks_materialized_features_feature_tag.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/materializedFeaturesFeatureTag:MaterializedFeaturesFeatureTag this "key"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MaterializedFeaturesFeatureTagArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Private Preview](https://img.shields.io/badge/Release_Stage-Private_Preview-blueviolet)](https://docs.databricks.com/aws/en/release-notes/release-types)

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "key"

          to = databricks_materialized_features_feature_tag.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/materializedFeaturesFeatureTag:MaterializedFeaturesFeatureTag this "key"
        ```

        :param str resource_name: The name of the resource.
        :param MaterializedFeaturesFeatureTagArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MaterializedFeaturesFeatureTagArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MaterializedFeaturesFeatureTagArgs.__new__(MaterializedFeaturesFeatureTagArgs)

            if key is None and not opts.urn:
                raise TypeError("Missing required property 'key'")
            __props__.__dict__["key"] = key
            __props__.__dict__["value"] = value
        super(MaterializedFeaturesFeatureTag, __self__).__init__(
            'databricks:index/materializedFeaturesFeatureTag:MaterializedFeaturesFeatureTag',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            key: Optional[pulumi.Input[_builtins.str]] = None,
            value: Optional[pulumi.Input[_builtins.str]] = None) -> 'MaterializedFeaturesFeatureTag':
        """
        Get an existing MaterializedFeaturesFeatureTag resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MaterializedFeaturesFeatureTagState.__new__(_MaterializedFeaturesFeatureTagState)

        __props__.__dict__["key"] = key
        __props__.__dict__["value"] = value
        return MaterializedFeaturesFeatureTag(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "value")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetClustersResult',
    'AwaitableGetClustersResult',
    'get_clusters',
    'get_clusters_output',
]

@pulumi.output_type
class GetClustersResult:
    """
    A collection of values returned by getClusters.
    """
    def __init__(__self__, cluster_name_contains=None, filter_by=None, id=None, ids=None, provider_config=None):
        if cluster_name_contains and not isinstance(cluster_name_contains, str):
            raise TypeError("Expected argument 'cluster_name_contains' to be a str")
        pulumi.set(__self__, "cluster_name_contains", cluster_name_contains)
        if filter_by and not isinstance(filter_by, dict):
            raise TypeError("Expected argument 'filter_by' to be a dict")
        pulumi.set(__self__, "filter_by", filter_by)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if provider_config and not isinstance(provider_config, dict):
            raise TypeError("Expected argument 'provider_config' to be a dict")
        pulumi.set(__self__, "provider_config", provider_config)

    @_builtins.property
    @pulumi.getter(name="clusterNameContains")
    def cluster_name_contains(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "cluster_name_contains")

    @_builtins.property
    @pulumi.getter(name="filterBy")
    def filter_by(self) -> Optional['outputs.GetClustersFilterByResult']:
        return pulumi.get(self, "filter_by")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def ids(self) -> Sequence[_builtins.str]:
        """
        list of Cluster ids
        """
        return pulumi.get(self, "ids")

    @_builtins.property
    @pulumi.getter(name="providerConfig")
    def provider_config(self) -> Optional['outputs.GetClustersProviderConfigResult']:
        return pulumi.get(self, "provider_config")


class AwaitableGetClustersResult(GetClustersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetClustersResult(
            cluster_name_contains=self.cluster_name_contains,
            filter_by=self.filter_by,
            id=self.id,
            ids=self.ids,
            provider_config=self.provider_config)


def get_clusters(cluster_name_contains: Optional[_builtins.str] = None,
                 filter_by: Optional[Union['GetClustersFilterByArgs', 'GetClustersFilterByArgsDict']] = None,
                 id: Optional[_builtins.str] = None,
                 ids: Optional[Sequence[_builtins.str]] = None,
                 provider_config: Optional[Union['GetClustersProviderConfigArgs', 'GetClustersProviderConfigArgsDict']] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetClustersResult:
    """
    Retrieves a list of Cluster ids, that were created by Pulumi or manually, with or without databricks_cluster_policy.

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    Retrieve cluster IDs for all clusters:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_clusters()
    ```

    Retrieve cluster IDs for all clusters having "Shared" in the cluster name:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all_shared = databricks.get_clusters(cluster_name_contains="shared")
    ```

    ### Filtering clusters

    Listing clusters can be slow for workspaces containing many clusters. Use filters to limit the number of clusters returned for better performance. You can filter clusters by state, source, policy, or pinned status:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all_running_clusters = databricks.get_clusters(filter_by={
        "cluster_states": ["RUNNING"],
    })
    all_clusters_with_policy = databricks.get_clusters(filter_by={
        "policy_id": "1234-5678-9012",
    })
    all_api_clusters = databricks.get_clusters(filter_by={
        "cluster_sources": ["API"],
    })
    all_pinned_clusters = databricks.get_clusters(filter_by={
        "is_pinned": True,
    })
    ```

    ## Related Resources

    The following resources are used in the same context:

    * End to end workspace management guide.
    * Cluster to create [Databricks Clusters](https://docs.databricks.com/clusters/index.html).
    * ClusterPolicy to create a Cluster policy, which limits the ability to create clusters based on a set of rules.
    * InstancePool to manage [instance pools](https://docs.databricks.com/clusters/instance-pools/index.html) to reduce cluster start and auto-scaling times by maintaining a set of idle, ready-to-use instances.
    * Job to manage [Databricks Jobs](https://docs.databricks.com/jobs.html) to run non-interactive code in a databricks_cluster.
    * Library to install a [library](https://docs.databricks.com/libraries/index.html) on databricks_cluster.
    * Pipeline to deploy [Lakeflow Declarative Pipelines](https://docs.databricks.com/aws/en/dlt).


    :param _builtins.str cluster_name_contains: Only return Cluster ids that match the given name string.
    :param Union['GetClustersFilterByArgs', 'GetClustersFilterByArgsDict'] filter_by: Filters to apply to the listed clusters. See filter_by Configuration Block below for details.
    :param Sequence[_builtins.str] ids: list of Cluster ids
    :param Union['GetClustersProviderConfigArgs', 'GetClustersProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
    """
    __args__ = dict()
    __args__['clusterNameContains'] = cluster_name_contains
    __args__['filterBy'] = filter_by
    __args__['id'] = id
    __args__['ids'] = ids
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getClusters:getClusters', __args__, opts=opts, typ=GetClustersResult).value

    return AwaitableGetClustersResult(
        cluster_name_contains=pulumi.get(__ret__, 'cluster_name_contains'),
        filter_by=pulumi.get(__ret__, 'filter_by'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        provider_config=pulumi.get(__ret__, 'provider_config'))
def get_clusters_output(cluster_name_contains: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        filter_by: Optional[pulumi.Input[Optional[Union['GetClustersFilterByArgs', 'GetClustersFilterByArgsDict']]]] = None,
                        id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                        ids: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                        provider_config: Optional[pulumi.Input[Optional[Union['GetClustersProviderConfigArgs', 'GetClustersProviderConfigArgsDict']]]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetClustersResult]:
    """
    Retrieves a list of Cluster ids, that were created by Pulumi or manually, with or without databricks_cluster_policy.

    > This data source can only be used with a workspace-level provider!

    ## Example Usage

    Retrieve cluster IDs for all clusters:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all = databricks.get_clusters()
    ```

    Retrieve cluster IDs for all clusters having "Shared" in the cluster name:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all_shared = databricks.get_clusters(cluster_name_contains="shared")
    ```

    ### Filtering clusters

    Listing clusters can be slow for workspaces containing many clusters. Use filters to limit the number of clusters returned for better performance. You can filter clusters by state, source, policy, or pinned status:

    ```python
    import pulumi
    import pulumi_databricks as databricks

    all_running_clusters = databricks.get_clusters(filter_by={
        "cluster_states": ["RUNNING"],
    })
    all_clusters_with_policy = databricks.get_clusters(filter_by={
        "policy_id": "1234-5678-9012",
    })
    all_api_clusters = databricks.get_clusters(filter_by={
        "cluster_sources": ["API"],
    })
    all_pinned_clusters = databricks.get_clusters(filter_by={
        "is_pinned": True,
    })
    ```

    ## Related Resources

    The following resources are used in the same context:

    * End to end workspace management guide.
    * Cluster to create [Databricks Clusters](https://docs.databricks.com/clusters/index.html).
    * ClusterPolicy to create a Cluster policy, which limits the ability to create clusters based on a set of rules.
    * InstancePool to manage [instance pools](https://docs.databricks.com/clusters/instance-pools/index.html) to reduce cluster start and auto-scaling times by maintaining a set of idle, ready-to-use instances.
    * Job to manage [Databricks Jobs](https://docs.databricks.com/jobs.html) to run non-interactive code in a databricks_cluster.
    * Library to install a [library](https://docs.databricks.com/libraries/index.html) on databricks_cluster.
    * Pipeline to deploy [Lakeflow Declarative Pipelines](https://docs.databricks.com/aws/en/dlt).


    :param _builtins.str cluster_name_contains: Only return Cluster ids that match the given name string.
    :param Union['GetClustersFilterByArgs', 'GetClustersFilterByArgsDict'] filter_by: Filters to apply to the listed clusters. See filter_by Configuration Block below for details.
    :param Sequence[_builtins.str] ids: list of Cluster ids
    :param Union['GetClustersProviderConfigArgs', 'GetClustersProviderConfigArgsDict'] provider_config: Configure the provider for management through account provider. This block consists of the following fields:
    """
    __args__ = dict()
    __args__['clusterNameContains'] = cluster_name_contains
    __args__['filterBy'] = filter_by
    __args__['id'] = id
    __args__['ids'] = ids
    __args__['providerConfig'] = provider_config
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getClusters:getClusters', __args__, opts=opts, typ=GetClustersResult)
    return __ret__.apply(lambda __response__: GetClustersResult(
        cluster_name_contains=pulumi.get(__response__, 'cluster_name_contains'),
        filter_by=pulumi.get(__response__, 'filter_by'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        provider_config=pulumi.get(__response__, 'provider_config')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DataQualityMonitorArgs', 'DataQualityMonitor']

@pulumi.input_type
class DataQualityMonitorArgs:
    def __init__(__self__, *,
                 object_id: pulumi.Input[_builtins.str],
                 object_type: pulumi.Input[_builtins.str],
                 anomaly_detection_config: Optional[pulumi.Input['DataQualityMonitorAnomalyDetectionConfigArgs']] = None,
                 data_profiling_config: Optional[pulumi.Input['DataQualityMonitorDataProfilingConfigArgs']] = None):
        """
        The set of arguments for constructing a DataQualityMonitor resource.
        :param pulumi.Input[_builtins.str] object_id: The UUID of the request object. It is `schema_id` for `schema`, and `table_id` for `table`.
               
               Find the `schema_id` from either:
               1. The [schema_id](https://docs.databricks.com/api/workspace/schemas/get#schema_id) of the `Schemas` resource.
               2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `schema` > go to the `Details` tab > the `Schema ID` field.
               
               Find the `table_id` from either:
               1. The [table_id](https://docs.databricks.com/api/workspace/tables/get#table_id) of the `Tables` resource.
               2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `table` > go to the `Details` tab > the `Table ID` field
        :param pulumi.Input[_builtins.str] object_type: The type of the monitored object. Can be one of the following: `schema` or `table`
        :param pulumi.Input['DataQualityMonitorAnomalyDetectionConfigArgs'] anomaly_detection_config: Anomaly Detection Configuration, applicable to `schema` object types
        :param pulumi.Input['DataQualityMonitorDataProfilingConfigArgs'] data_profiling_config: Data Profiling Configuration, applicable to `table` object types. Exactly one `Analysis Configuration`
               must be present
        """
        pulumi.set(__self__, "object_id", object_id)
        pulumi.set(__self__, "object_type", object_type)
        if anomaly_detection_config is not None:
            pulumi.set(__self__, "anomaly_detection_config", anomaly_detection_config)
        if data_profiling_config is not None:
            pulumi.set(__self__, "data_profiling_config", data_profiling_config)

    @_builtins.property
    @pulumi.getter(name="objectId")
    def object_id(self) -> pulumi.Input[_builtins.str]:
        """
        The UUID of the request object. It is `schema_id` for `schema`, and `table_id` for `table`.

        Find the `schema_id` from either:
        1. The [schema_id](https://docs.databricks.com/api/workspace/schemas/get#schema_id) of the `Schemas` resource.
        2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `schema` > go to the `Details` tab > the `Schema ID` field.

        Find the `table_id` from either:
        1. The [table_id](https://docs.databricks.com/api/workspace/tables/get#table_id) of the `Tables` resource.
        2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `table` > go to the `Details` tab > the `Table ID` field
        """
        return pulumi.get(self, "object_id")

    @object_id.setter
    def object_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "object_id", value)

    @_builtins.property
    @pulumi.getter(name="objectType")
    def object_type(self) -> pulumi.Input[_builtins.str]:
        """
        The type of the monitored object. Can be one of the following: `schema` or `table`
        """
        return pulumi.get(self, "object_type")

    @object_type.setter
    def object_type(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "object_type", value)

    @_builtins.property
    @pulumi.getter(name="anomalyDetectionConfig")
    def anomaly_detection_config(self) -> Optional[pulumi.Input['DataQualityMonitorAnomalyDetectionConfigArgs']]:
        """
        Anomaly Detection Configuration, applicable to `schema` object types
        """
        return pulumi.get(self, "anomaly_detection_config")

    @anomaly_detection_config.setter
    def anomaly_detection_config(self, value: Optional[pulumi.Input['DataQualityMonitorAnomalyDetectionConfigArgs']]):
        pulumi.set(self, "anomaly_detection_config", value)

    @_builtins.property
    @pulumi.getter(name="dataProfilingConfig")
    def data_profiling_config(self) -> Optional[pulumi.Input['DataQualityMonitorDataProfilingConfigArgs']]:
        """
        Data Profiling Configuration, applicable to `table` object types. Exactly one `Analysis Configuration`
        must be present
        """
        return pulumi.get(self, "data_profiling_config")

    @data_profiling_config.setter
    def data_profiling_config(self, value: Optional[pulumi.Input['DataQualityMonitorDataProfilingConfigArgs']]):
        pulumi.set(self, "data_profiling_config", value)


@pulumi.input_type
class _DataQualityMonitorState:
    def __init__(__self__, *,
                 anomaly_detection_config: Optional[pulumi.Input['DataQualityMonitorAnomalyDetectionConfigArgs']] = None,
                 data_profiling_config: Optional[pulumi.Input['DataQualityMonitorDataProfilingConfigArgs']] = None,
                 object_id: Optional[pulumi.Input[_builtins.str]] = None,
                 object_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DataQualityMonitor resources.
        :param pulumi.Input['DataQualityMonitorAnomalyDetectionConfigArgs'] anomaly_detection_config: Anomaly Detection Configuration, applicable to `schema` object types
        :param pulumi.Input['DataQualityMonitorDataProfilingConfigArgs'] data_profiling_config: Data Profiling Configuration, applicable to `table` object types. Exactly one `Analysis Configuration`
               must be present
        :param pulumi.Input[_builtins.str] object_id: The UUID of the request object. It is `schema_id` for `schema`, and `table_id` for `table`.
               
               Find the `schema_id` from either:
               1. The [schema_id](https://docs.databricks.com/api/workspace/schemas/get#schema_id) of the `Schemas` resource.
               2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `schema` > go to the `Details` tab > the `Schema ID` field.
               
               Find the `table_id` from either:
               1. The [table_id](https://docs.databricks.com/api/workspace/tables/get#table_id) of the `Tables` resource.
               2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `table` > go to the `Details` tab > the `Table ID` field
        :param pulumi.Input[_builtins.str] object_type: The type of the monitored object. Can be one of the following: `schema` or `table`
        """
        if anomaly_detection_config is not None:
            pulumi.set(__self__, "anomaly_detection_config", anomaly_detection_config)
        if data_profiling_config is not None:
            pulumi.set(__self__, "data_profiling_config", data_profiling_config)
        if object_id is not None:
            pulumi.set(__self__, "object_id", object_id)
        if object_type is not None:
            pulumi.set(__self__, "object_type", object_type)

    @_builtins.property
    @pulumi.getter(name="anomalyDetectionConfig")
    def anomaly_detection_config(self) -> Optional[pulumi.Input['DataQualityMonitorAnomalyDetectionConfigArgs']]:
        """
        Anomaly Detection Configuration, applicable to `schema` object types
        """
        return pulumi.get(self, "anomaly_detection_config")

    @anomaly_detection_config.setter
    def anomaly_detection_config(self, value: Optional[pulumi.Input['DataQualityMonitorAnomalyDetectionConfigArgs']]):
        pulumi.set(self, "anomaly_detection_config", value)

    @_builtins.property
    @pulumi.getter(name="dataProfilingConfig")
    def data_profiling_config(self) -> Optional[pulumi.Input['DataQualityMonitorDataProfilingConfigArgs']]:
        """
        Data Profiling Configuration, applicable to `table` object types. Exactly one `Analysis Configuration`
        must be present
        """
        return pulumi.get(self, "data_profiling_config")

    @data_profiling_config.setter
    def data_profiling_config(self, value: Optional[pulumi.Input['DataQualityMonitorDataProfilingConfigArgs']]):
        pulumi.set(self, "data_profiling_config", value)

    @_builtins.property
    @pulumi.getter(name="objectId")
    def object_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The UUID of the request object. It is `schema_id` for `schema`, and `table_id` for `table`.

        Find the `schema_id` from either:
        1. The [schema_id](https://docs.databricks.com/api/workspace/schemas/get#schema_id) of the `Schemas` resource.
        2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `schema` > go to the `Details` tab > the `Schema ID` field.

        Find the `table_id` from either:
        1. The [table_id](https://docs.databricks.com/api/workspace/tables/get#table_id) of the `Tables` resource.
        2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `table` > go to the `Details` tab > the `Table ID` field
        """
        return pulumi.get(self, "object_id")

    @object_id.setter
    def object_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "object_id", value)

    @_builtins.property
    @pulumi.getter(name="objectType")
    def object_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of the monitored object. Can be one of the following: `schema` or `table`
        """
        return pulumi.get(self, "object_type")

    @object_type.setter
    def object_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "object_type", value)


@pulumi.type_token("databricks:index/dataQualityMonitor:DataQualityMonitor")
class DataQualityMonitor(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 anomaly_detection_config: Optional[pulumi.Input[Union['DataQualityMonitorAnomalyDetectionConfigArgs', 'DataQualityMonitorAnomalyDetectionConfigArgsDict']]] = None,
                 data_profiling_config: Optional[pulumi.Input[Union['DataQualityMonitorDataProfilingConfigArgs', 'DataQualityMonitorDataProfilingConfigArgsDict']]] = None,
                 object_id: Optional[pulumi.Input[_builtins.str]] = None,
                 object_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

        This resource allows you to set up data quality monitoring checks for Unity Catalog objects, currently schema and table.

        For the `table` `object_type`, you must either:
        1. be an owner of the table's parent catalog, have **USE_SCHEMA** on the table's parent schema, and have **SELECT** access on the table
        2. have **USE_CATALOG** on the table's parent catalog, be an owner of the table's parent schema, and have **SELECT** access on the table.
        3. have the following permissions:
           - **USE_CATALOG** on the table's parent catalog
           - **USE_SCHEMA** on the table's parent schema
           - be an owner of the table.

        > **Note** This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.Schema("this",
            catalog_name="my_catalog",
            name="my_schema")
        this_data_quality_monitor = databricks.DataQualityMonitor("this",
            object_type="schema",
            object_id=this.schema_id,
            anomaly_detection_config={})
        ```

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "object_type,object_id"

          to = databricks_data_quality_monitor.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/dataQualityMonitor:DataQualityMonitor this "object_type,object_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['DataQualityMonitorAnomalyDetectionConfigArgs', 'DataQualityMonitorAnomalyDetectionConfigArgsDict']] anomaly_detection_config: Anomaly Detection Configuration, applicable to `schema` object types
        :param pulumi.Input[Union['DataQualityMonitorDataProfilingConfigArgs', 'DataQualityMonitorDataProfilingConfigArgsDict']] data_profiling_config: Data Profiling Configuration, applicable to `table` object types. Exactly one `Analysis Configuration`
               must be present
        :param pulumi.Input[_builtins.str] object_id: The UUID of the request object. It is `schema_id` for `schema`, and `table_id` for `table`.
               
               Find the `schema_id` from either:
               1. The [schema_id](https://docs.databricks.com/api/workspace/schemas/get#schema_id) of the `Schemas` resource.
               2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `schema` > go to the `Details` tab > the `Schema ID` field.
               
               Find the `table_id` from either:
               1. The [table_id](https://docs.databricks.com/api/workspace/tables/get#table_id) of the `Tables` resource.
               2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `table` > go to the `Details` tab > the `Table ID` field
        :param pulumi.Input[_builtins.str] object_type: The type of the monitored object. Can be one of the following: `schema` or `table`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DataQualityMonitorArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

        This resource allows you to set up data quality monitoring checks for Unity Catalog objects, currently schema and table.

        For the `table` `object_type`, you must either:
        1. be an owner of the table's parent catalog, have **USE_SCHEMA** on the table's parent schema, and have **SELECT** access on the table
        2. have **USE_CATALOG** on the table's parent catalog, be an owner of the table's parent schema, and have **SELECT** access on the table.
        3. have the following permissions:
           - **USE_CATALOG** on the table's parent catalog
           - **USE_SCHEMA** on the table's parent schema
           - be an owner of the table.

        > **Note** This resource can only be used with a workspace-level provider!

        ## Example Usage

        ```python
        import pulumi
        import pulumi_databricks as databricks

        this = databricks.Schema("this",
            catalog_name="my_catalog",
            name="my_schema")
        this_data_quality_monitor = databricks.DataQualityMonitor("this",
            object_type="schema",
            object_id=this.schema_id,
            anomaly_detection_config={})
        ```

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "object_type,object_id"

          to = databricks_data_quality_monitor.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/dataQualityMonitor:DataQualityMonitor this "object_type,object_id"
        ```

        :param str resource_name: The name of the resource.
        :param DataQualityMonitorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DataQualityMonitorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 anomaly_detection_config: Optional[pulumi.Input[Union['DataQualityMonitorAnomalyDetectionConfigArgs', 'DataQualityMonitorAnomalyDetectionConfigArgsDict']]] = None,
                 data_profiling_config: Optional[pulumi.Input[Union['DataQualityMonitorDataProfilingConfigArgs', 'DataQualityMonitorDataProfilingConfigArgsDict']]] = None,
                 object_id: Optional[pulumi.Input[_builtins.str]] = None,
                 object_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DataQualityMonitorArgs.__new__(DataQualityMonitorArgs)

            __props__.__dict__["anomaly_detection_config"] = anomaly_detection_config
            __props__.__dict__["data_profiling_config"] = data_profiling_config
            if object_id is None and not opts.urn:
                raise TypeError("Missing required property 'object_id'")
            __props__.__dict__["object_id"] = object_id
            if object_type is None and not opts.urn:
                raise TypeError("Missing required property 'object_type'")
            __props__.__dict__["object_type"] = object_type
        super(DataQualityMonitor, __self__).__init__(
            'databricks:index/dataQualityMonitor:DataQualityMonitor',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            anomaly_detection_config: Optional[pulumi.Input[Union['DataQualityMonitorAnomalyDetectionConfigArgs', 'DataQualityMonitorAnomalyDetectionConfigArgsDict']]] = None,
            data_profiling_config: Optional[pulumi.Input[Union['DataQualityMonitorDataProfilingConfigArgs', 'DataQualityMonitorDataProfilingConfigArgsDict']]] = None,
            object_id: Optional[pulumi.Input[_builtins.str]] = None,
            object_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'DataQualityMonitor':
        """
        Get an existing DataQualityMonitor resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['DataQualityMonitorAnomalyDetectionConfigArgs', 'DataQualityMonitorAnomalyDetectionConfigArgsDict']] anomaly_detection_config: Anomaly Detection Configuration, applicable to `schema` object types
        :param pulumi.Input[Union['DataQualityMonitorDataProfilingConfigArgs', 'DataQualityMonitorDataProfilingConfigArgsDict']] data_profiling_config: Data Profiling Configuration, applicable to `table` object types. Exactly one `Analysis Configuration`
               must be present
        :param pulumi.Input[_builtins.str] object_id: The UUID of the request object. It is `schema_id` for `schema`, and `table_id` for `table`.
               
               Find the `schema_id` from either:
               1. The [schema_id](https://docs.databricks.com/api/workspace/schemas/get#schema_id) of the `Schemas` resource.
               2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `schema` > go to the `Details` tab > the `Schema ID` field.
               
               Find the `table_id` from either:
               1. The [table_id](https://docs.databricks.com/api/workspace/tables/get#table_id) of the `Tables` resource.
               2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `table` > go to the `Details` tab > the `Table ID` field
        :param pulumi.Input[_builtins.str] object_type: The type of the monitored object. Can be one of the following: `schema` or `table`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DataQualityMonitorState.__new__(_DataQualityMonitorState)

        __props__.__dict__["anomaly_detection_config"] = anomaly_detection_config
        __props__.__dict__["data_profiling_config"] = data_profiling_config
        __props__.__dict__["object_id"] = object_id
        __props__.__dict__["object_type"] = object_type
        return DataQualityMonitor(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="anomalyDetectionConfig")
    def anomaly_detection_config(self) -> pulumi.Output[Optional['outputs.DataQualityMonitorAnomalyDetectionConfig']]:
        """
        Anomaly Detection Configuration, applicable to `schema` object types
        """
        return pulumi.get(self, "anomaly_detection_config")

    @_builtins.property
    @pulumi.getter(name="dataProfilingConfig")
    def data_profiling_config(self) -> pulumi.Output[Optional['outputs.DataQualityMonitorDataProfilingConfig']]:
        """
        Data Profiling Configuration, applicable to `table` object types. Exactly one `Analysis Configuration`
        must be present
        """
        return pulumi.get(self, "data_profiling_config")

    @_builtins.property
    @pulumi.getter(name="objectId")
    def object_id(self) -> pulumi.Output[_builtins.str]:
        """
        The UUID of the request object. It is `schema_id` for `schema`, and `table_id` for `table`.

        Find the `schema_id` from either:
        1. The [schema_id](https://docs.databricks.com/api/workspace/schemas/get#schema_id) of the `Schemas` resource.
        2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `schema` > go to the `Details` tab > the `Schema ID` field.

        Find the `table_id` from either:
        1. The [table_id](https://docs.databricks.com/api/workspace/tables/get#table_id) of the `Tables` resource.
        2. In [Catalog Explorer](https://docs.databricks.com/aws/en/catalog-explorer/) > select the `table` > go to the `Details` tab > the `Table ID` field
        """
        return pulumi.get(self, "object_id")

    @_builtins.property
    @pulumi.getter(name="objectType")
    def object_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of the monitored object. Can be one of the following: `schema` or `table`
        """
        return pulumi.get(self, "object_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AlertV2Args', 'AlertV2']

@pulumi.input_type
class AlertV2Args:
    def __init__(__self__, *,
                 display_name: pulumi.Input[_builtins.str],
                 evaluation: pulumi.Input['AlertV2EvaluationArgs'],
                 query_text: pulumi.Input[_builtins.str],
                 schedule: pulumi.Input['AlertV2ScheduleArgs'],
                 warehouse_id: pulumi.Input[_builtins.str],
                 custom_description: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_summary: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_path: Optional[pulumi.Input[_builtins.str]] = None,
                 run_as: Optional[pulumi.Input['AlertV2RunAsArgs']] = None,
                 run_as_user_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AlertV2 resource.
        :param pulumi.Input[_builtins.str] display_name: The display name of the alert
        :param pulumi.Input[_builtins.str] query_text: Text of the query to be run
        :param pulumi.Input[_builtins.str] warehouse_id: ID of the SQL warehouse attached to the alert
        :param pulumi.Input[_builtins.str] custom_description: Custom description for the alert. support mustache template
        :param pulumi.Input[_builtins.str] custom_summary: Custom summary for the alert. support mustache template
        :param pulumi.Input[_builtins.str] parent_path: The workspace path of the folder containing the alert. Can only be set on create, and cannot be updated
        :param pulumi.Input['AlertV2RunAsArgs'] run_as: Specifies the identity that will be used to run the alert.
               This field allows you to configure alerts to run as a specific user or service principal.
               - For user identity: Set `user_name` to the email of an active workspace user. Users can only set this to their own email.
               - For service principal: Set `service_principal_name` to the application ID. Requires the `servicePrincipal/user` role.
               If not specified, the alert will run as the request user
        :param pulumi.Input[_builtins.str] run_as_user_name: The run as username or application ID of service principal.
               On Create and Update, this field can be set to application ID of an active service principal. Setting this field requires the servicePrincipal/user role.
               Deprecated: Use `run_as` field instead. This field will be removed in a future release
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "evaluation", evaluation)
        pulumi.set(__self__, "query_text", query_text)
        pulumi.set(__self__, "schedule", schedule)
        pulumi.set(__self__, "warehouse_id", warehouse_id)
        if custom_description is not None:
            pulumi.set(__self__, "custom_description", custom_description)
        if custom_summary is not None:
            pulumi.set(__self__, "custom_summary", custom_summary)
        if parent_path is not None:
            pulumi.set(__self__, "parent_path", parent_path)
        if run_as is not None:
            pulumi.set(__self__, "run_as", run_as)
        if run_as_user_name is not None:
            pulumi.set(__self__, "run_as_user_name", run_as_user_name)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[_builtins.str]:
        """
        The display name of the alert
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter
    def evaluation(self) -> pulumi.Input['AlertV2EvaluationArgs']:
        return pulumi.get(self, "evaluation")

    @evaluation.setter
    def evaluation(self, value: pulumi.Input['AlertV2EvaluationArgs']):
        pulumi.set(self, "evaluation", value)

    @_builtins.property
    @pulumi.getter(name="queryText")
    def query_text(self) -> pulumi.Input[_builtins.str]:
        """
        Text of the query to be run
        """
        return pulumi.get(self, "query_text")

    @query_text.setter
    def query_text(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "query_text", value)

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> pulumi.Input['AlertV2ScheduleArgs']:
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: pulumi.Input['AlertV2ScheduleArgs']):
        pulumi.set(self, "schedule", value)

    @_builtins.property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the SQL warehouse attached to the alert
        """
        return pulumi.get(self, "warehouse_id")

    @warehouse_id.setter
    def warehouse_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "warehouse_id", value)

    @_builtins.property
    @pulumi.getter(name="customDescription")
    def custom_description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom description for the alert. support mustache template
        """
        return pulumi.get(self, "custom_description")

    @custom_description.setter
    def custom_description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "custom_description", value)

    @_builtins.property
    @pulumi.getter(name="customSummary")
    def custom_summary(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom summary for the alert. support mustache template
        """
        return pulumi.get(self, "custom_summary")

    @custom_summary.setter
    def custom_summary(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "custom_summary", value)

    @_builtins.property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The workspace path of the folder containing the alert. Can only be set on create, and cannot be updated
        """
        return pulumi.get(self, "parent_path")

    @parent_path.setter
    def parent_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_path", value)

    @_builtins.property
    @pulumi.getter(name="runAs")
    def run_as(self) -> Optional[pulumi.Input['AlertV2RunAsArgs']]:
        """
        Specifies the identity that will be used to run the alert.
        This field allows you to configure alerts to run as a specific user or service principal.
        - For user identity: Set `user_name` to the email of an active workspace user. Users can only set this to their own email.
        - For service principal: Set `service_principal_name` to the application ID. Requires the `servicePrincipal/user` role.
        If not specified, the alert will run as the request user
        """
        return pulumi.get(self, "run_as")

    @run_as.setter
    def run_as(self, value: Optional[pulumi.Input['AlertV2RunAsArgs']]):
        pulumi.set(self, "run_as", value)

    @_builtins.property
    @pulumi.getter(name="runAsUserName")
    def run_as_user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The run as username or application ID of service principal.
        On Create and Update, this field can be set to application ID of an active service principal. Setting this field requires the servicePrincipal/user role.
        Deprecated: Use `run_as` field instead. This field will be removed in a future release
        """
        return pulumi.get(self, "run_as_user_name")

    @run_as_user_name.setter
    def run_as_user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "run_as_user_name", value)


@pulumi.input_type
class _AlertV2State:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_description: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_summary: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 effective_run_as: Optional[pulumi.Input['AlertV2EffectiveRunAsArgs']] = None,
                 evaluation: Optional[pulumi.Input['AlertV2EvaluationArgs']] = None,
                 lifecycle_state: Optional[pulumi.Input[_builtins.str]] = None,
                 owner_user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 parent_path: Optional[pulumi.Input[_builtins.str]] = None,
                 query_text: Optional[pulumi.Input[_builtins.str]] = None,
                 run_as: Optional[pulumi.Input['AlertV2RunAsArgs']] = None,
                 run_as_user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 schedule: Optional[pulumi.Input['AlertV2ScheduleArgs']] = None,
                 update_time: Optional[pulumi.Input[_builtins.str]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AlertV2 resources.
        :param pulumi.Input[_builtins.str] create_time: (string) - The timestamp indicating when the alert was created
        :param pulumi.Input[_builtins.str] custom_description: Custom description for the alert. support mustache template
        :param pulumi.Input[_builtins.str] custom_summary: Custom summary for the alert. support mustache template
        :param pulumi.Input[_builtins.str] display_name: The display name of the alert
        :param pulumi.Input['AlertV2EffectiveRunAsArgs'] effective_run_as: (AlertV2RunAs) - The actual identity that will be used to execute the alert.
               This is an output-only field that shows the resolved run-as identity after applying
               permissions and defaults
        :param pulumi.Input[_builtins.str] lifecycle_state: (string) - Indicates whether the query is trashed. Possible values are: `ACTIVE`, `DELETED`
        :param pulumi.Input[_builtins.str] owner_user_name: (string) - The owner's username. This field is set to "Unavailable" if the user has been deleted
        :param pulumi.Input[_builtins.str] parent_path: The workspace path of the folder containing the alert. Can only be set on create, and cannot be updated
        :param pulumi.Input[_builtins.str] query_text: Text of the query to be run
        :param pulumi.Input['AlertV2RunAsArgs'] run_as: Specifies the identity that will be used to run the alert.
               This field allows you to configure alerts to run as a specific user or service principal.
               - For user identity: Set `user_name` to the email of an active workspace user. Users can only set this to their own email.
               - For service principal: Set `service_principal_name` to the application ID. Requires the `servicePrincipal/user` role.
               If not specified, the alert will run as the request user
        :param pulumi.Input[_builtins.str] run_as_user_name: The run as username or application ID of service principal.
               On Create and Update, this field can be set to application ID of an active service principal. Setting this field requires the servicePrincipal/user role.
               Deprecated: Use `run_as` field instead. This field will be removed in a future release
        :param pulumi.Input[_builtins.str] update_time: (string) - The timestamp indicating when the alert was updated
        :param pulumi.Input[_builtins.str] warehouse_id: ID of the SQL warehouse attached to the alert
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if custom_description is not None:
            pulumi.set(__self__, "custom_description", custom_description)
        if custom_summary is not None:
            pulumi.set(__self__, "custom_summary", custom_summary)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if effective_run_as is not None:
            pulumi.set(__self__, "effective_run_as", effective_run_as)
        if evaluation is not None:
            pulumi.set(__self__, "evaluation", evaluation)
        if lifecycle_state is not None:
            pulumi.set(__self__, "lifecycle_state", lifecycle_state)
        if owner_user_name is not None:
            pulumi.set(__self__, "owner_user_name", owner_user_name)
        if parent_path is not None:
            pulumi.set(__self__, "parent_path", parent_path)
        if query_text is not None:
            pulumi.set(__self__, "query_text", query_text)
        if run_as is not None:
            pulumi.set(__self__, "run_as", run_as)
        if run_as_user_name is not None:
            pulumi.set(__self__, "run_as_user_name", run_as_user_name)
        if schedule is not None:
            pulumi.set(__self__, "schedule", schedule)
        if update_time is not None:
            pulumi.set(__self__, "update_time", update_time)
        if warehouse_id is not None:
            pulumi.set(__self__, "warehouse_id", warehouse_id)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The timestamp indicating when the alert was created
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "create_time", value)

    @_builtins.property
    @pulumi.getter(name="customDescription")
    def custom_description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom description for the alert. support mustache template
        """
        return pulumi.get(self, "custom_description")

    @custom_description.setter
    def custom_description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "custom_description", value)

    @_builtins.property
    @pulumi.getter(name="customSummary")
    def custom_summary(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom summary for the alert. support mustache template
        """
        return pulumi.get(self, "custom_summary")

    @custom_summary.setter
    def custom_summary(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "custom_summary", value)

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The display name of the alert
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "display_name", value)

    @_builtins.property
    @pulumi.getter(name="effectiveRunAs")
    def effective_run_as(self) -> Optional[pulumi.Input['AlertV2EffectiveRunAsArgs']]:
        """
        (AlertV2RunAs) - The actual identity that will be used to execute the alert.
        This is an output-only field that shows the resolved run-as identity after applying
        permissions and defaults
        """
        return pulumi.get(self, "effective_run_as")

    @effective_run_as.setter
    def effective_run_as(self, value: Optional[pulumi.Input['AlertV2EffectiveRunAsArgs']]):
        pulumi.set(self, "effective_run_as", value)

    @_builtins.property
    @pulumi.getter
    def evaluation(self) -> Optional[pulumi.Input['AlertV2EvaluationArgs']]:
        return pulumi.get(self, "evaluation")

    @evaluation.setter
    def evaluation(self, value: Optional[pulumi.Input['AlertV2EvaluationArgs']]):
        pulumi.set(self, "evaluation", value)

    @_builtins.property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - Indicates whether the query is trashed. Possible values are: `ACTIVE`, `DELETED`
        """
        return pulumi.get(self, "lifecycle_state")

    @lifecycle_state.setter
    def lifecycle_state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "lifecycle_state", value)

    @_builtins.property
    @pulumi.getter(name="ownerUserName")
    def owner_user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The owner's username. This field is set to "Unavailable" if the user has been deleted
        """
        return pulumi.get(self, "owner_user_name")

    @owner_user_name.setter
    def owner_user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "owner_user_name", value)

    @_builtins.property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The workspace path of the folder containing the alert. Can only be set on create, and cannot be updated
        """
        return pulumi.get(self, "parent_path")

    @parent_path.setter
    def parent_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "parent_path", value)

    @_builtins.property
    @pulumi.getter(name="queryText")
    def query_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Text of the query to be run
        """
        return pulumi.get(self, "query_text")

    @query_text.setter
    def query_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "query_text", value)

    @_builtins.property
    @pulumi.getter(name="runAs")
    def run_as(self) -> Optional[pulumi.Input['AlertV2RunAsArgs']]:
        """
        Specifies the identity that will be used to run the alert.
        This field allows you to configure alerts to run as a specific user or service principal.
        - For user identity: Set `user_name` to the email of an active workspace user. Users can only set this to their own email.
        - For service principal: Set `service_principal_name` to the application ID. Requires the `servicePrincipal/user` role.
        If not specified, the alert will run as the request user
        """
        return pulumi.get(self, "run_as")

    @run_as.setter
    def run_as(self, value: Optional[pulumi.Input['AlertV2RunAsArgs']]):
        pulumi.set(self, "run_as", value)

    @_builtins.property
    @pulumi.getter(name="runAsUserName")
    def run_as_user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The run as username or application ID of service principal.
        On Create and Update, this field can be set to application ID of an active service principal. Setting this field requires the servicePrincipal/user role.
        Deprecated: Use `run_as` field instead. This field will be removed in a future release
        """
        return pulumi.get(self, "run_as_user_name")

    @run_as_user_name.setter
    def run_as_user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "run_as_user_name", value)

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> Optional[pulumi.Input['AlertV2ScheduleArgs']]:
        return pulumi.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: Optional[pulumi.Input['AlertV2ScheduleArgs']]):
        pulumi.set(self, "schedule", value)

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (string) - The timestamp indicating when the alert was updated
        """
        return pulumi.get(self, "update_time")

    @update_time.setter
    def update_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "update_time", value)

    @_builtins.property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the SQL warehouse attached to the alert
        """
        return pulumi.get(self, "warehouse_id")

    @warehouse_id.setter
    def warehouse_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "warehouse_id", value)


@pulumi.type_token("databricks:index/alertV2:AlertV2")
class AlertV2(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_description: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_summary: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 evaluation: Optional[pulumi.Input[Union['AlertV2EvaluationArgs', 'AlertV2EvaluationArgsDict']]] = None,
                 parent_path: Optional[pulumi.Input[_builtins.str]] = None,
                 query_text: Optional[pulumi.Input[_builtins.str]] = None,
                 run_as: Optional[pulumi.Input[Union['AlertV2RunAsArgs', 'AlertV2RunAsArgsDict']]] = None,
                 run_as_user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 schedule: Optional[pulumi.Input[Union['AlertV2ScheduleArgs', 'AlertV2ScheduleArgsDict']]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

        The Alert v2 resource allows you to manage SQL alerts in Databricks SQL. Alerts monitor query results and notify you when specific conditions are met.

        Alerts run on a schedule and evaluate query results against defined thresholds. When an alert is triggered, notifications can be sent to specified users or destinations.

        ## Example Usage

        ### Basic Alert Example
        This example creates a basic alert that monitors a query and sends notifications to a user when the value exceeds a threshold:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        basic_alert = databricks.AlertV2("basic_alert",
            display_name="High Error Rate Alert",
            query_text="SELECT count(*) as error_count FROM logs WHERE level = 'ERROR' AND timestamp > now() - interval 1 hour",
            warehouse_id="a7066a8ef796be84",
            parent_path="/Users/user@example.com",
            evaluation={
                "source": {
                    "name": "error_count",
                    "display": "Error Count",
                    "aggregation": "COUNT",
                },
                "comparison_operator": "GREATER_THAN",
                "threshold": {
                    "value": {
                        "double_value": 100,
                    },
                },
                "empty_result_state": "OK",
                "notification": {
                    "subscriptions": [{
                        "user_email": "user@example.com",
                    }],
                    "notify_on_ok": True,
                },
            },
            schedule={
                "quartz_cron_schedule": "0 0/15 * * * ?",
                "timezone_id": "America/Los_Angeles",
                "pause_status": "UNPAUSED",
            })
        ```

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "id"

          to = databricks_alert_v2.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/alertV2:AlertV2 this "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] custom_description: Custom description for the alert. support mustache template
        :param pulumi.Input[_builtins.str] custom_summary: Custom summary for the alert. support mustache template
        :param pulumi.Input[_builtins.str] display_name: The display name of the alert
        :param pulumi.Input[_builtins.str] parent_path: The workspace path of the folder containing the alert. Can only be set on create, and cannot be updated
        :param pulumi.Input[_builtins.str] query_text: Text of the query to be run
        :param pulumi.Input[Union['AlertV2RunAsArgs', 'AlertV2RunAsArgsDict']] run_as: Specifies the identity that will be used to run the alert.
               This field allows you to configure alerts to run as a specific user or service principal.
               - For user identity: Set `user_name` to the email of an active workspace user. Users can only set this to their own email.
               - For service principal: Set `service_principal_name` to the application ID. Requires the `servicePrincipal/user` role.
               If not specified, the alert will run as the request user
        :param pulumi.Input[_builtins.str] run_as_user_name: The run as username or application ID of service principal.
               On Create and Update, this field can be set to application ID of an active service principal. Setting this field requires the servicePrincipal/user role.
               Deprecated: Use `run_as` field instead. This field will be removed in a future release
        :param pulumi.Input[_builtins.str] warehouse_id: ID of the SQL warehouse attached to the alert
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AlertV2Args,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

        The Alert v2 resource allows you to manage SQL alerts in Databricks SQL. Alerts monitor query results and notify you when specific conditions are met.

        Alerts run on a schedule and evaluate query results against defined thresholds. When an alert is triggered, notifications can be sent to specified users or destinations.

        ## Example Usage

        ### Basic Alert Example
        This example creates a basic alert that monitors a query and sends notifications to a user when the value exceeds a threshold:

        ```python
        import pulumi
        import pulumi_databricks as databricks

        basic_alert = databricks.AlertV2("basic_alert",
            display_name="High Error Rate Alert",
            query_text="SELECT count(*) as error_count FROM logs WHERE level = 'ERROR' AND timestamp > now() - interval 1 hour",
            warehouse_id="a7066a8ef796be84",
            parent_path="/Users/user@example.com",
            evaluation={
                "source": {
                    "name": "error_count",
                    "display": "Error Count",
                    "aggregation": "COUNT",
                },
                "comparison_operator": "GREATER_THAN",
                "threshold": {
                    "value": {
                        "double_value": 100,
                    },
                },
                "empty_result_state": "OK",
                "notification": {
                    "subscriptions": [{
                        "user_email": "user@example.com",
                    }],
                    "notify_on_ok": True,
                },
            },
            schedule={
                "quartz_cron_schedule": "0 0/15 * * * ?",
                "timezone_id": "America/Los_Angeles",
                "pause_status": "UNPAUSED",
            })
        ```

        ## Import

        As of Pulumi v1.5, resources can be imported through configuration.

        hcl

        import {

          id = "id"

          to = databricks_alert_v2.this

        }

        If you are using an older version of Pulumi, import the resource using the `pulumi import` command as follows:

        ```sh
        $ pulumi import databricks:index/alertV2:AlertV2 this "id"
        ```

        :param str resource_name: The name of the resource.
        :param AlertV2Args args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AlertV2Args, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 custom_description: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_summary: Optional[pulumi.Input[_builtins.str]] = None,
                 display_name: Optional[pulumi.Input[_builtins.str]] = None,
                 evaluation: Optional[pulumi.Input[Union['AlertV2EvaluationArgs', 'AlertV2EvaluationArgsDict']]] = None,
                 parent_path: Optional[pulumi.Input[_builtins.str]] = None,
                 query_text: Optional[pulumi.Input[_builtins.str]] = None,
                 run_as: Optional[pulumi.Input[Union['AlertV2RunAsArgs', 'AlertV2RunAsArgsDict']]] = None,
                 run_as_user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 schedule: Optional[pulumi.Input[Union['AlertV2ScheduleArgs', 'AlertV2ScheduleArgsDict']]] = None,
                 warehouse_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AlertV2Args.__new__(AlertV2Args)

            __props__.__dict__["custom_description"] = custom_description
            __props__.__dict__["custom_summary"] = custom_summary
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            if evaluation is None and not opts.urn:
                raise TypeError("Missing required property 'evaluation'")
            __props__.__dict__["evaluation"] = evaluation
            __props__.__dict__["parent_path"] = parent_path
            if query_text is None and not opts.urn:
                raise TypeError("Missing required property 'query_text'")
            __props__.__dict__["query_text"] = query_text
            __props__.__dict__["run_as"] = run_as
            __props__.__dict__["run_as_user_name"] = run_as_user_name
            if schedule is None and not opts.urn:
                raise TypeError("Missing required property 'schedule'")
            __props__.__dict__["schedule"] = schedule
            if warehouse_id is None and not opts.urn:
                raise TypeError("Missing required property 'warehouse_id'")
            __props__.__dict__["warehouse_id"] = warehouse_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["effective_run_as"] = None
            __props__.__dict__["lifecycle_state"] = None
            __props__.__dict__["owner_user_name"] = None
            __props__.__dict__["update_time"] = None
        super(AlertV2, __self__).__init__(
            'databricks:index/alertV2:AlertV2',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[_builtins.str]] = None,
            custom_description: Optional[pulumi.Input[_builtins.str]] = None,
            custom_summary: Optional[pulumi.Input[_builtins.str]] = None,
            display_name: Optional[pulumi.Input[_builtins.str]] = None,
            effective_run_as: Optional[pulumi.Input[Union['AlertV2EffectiveRunAsArgs', 'AlertV2EffectiveRunAsArgsDict']]] = None,
            evaluation: Optional[pulumi.Input[Union['AlertV2EvaluationArgs', 'AlertV2EvaluationArgsDict']]] = None,
            lifecycle_state: Optional[pulumi.Input[_builtins.str]] = None,
            owner_user_name: Optional[pulumi.Input[_builtins.str]] = None,
            parent_path: Optional[pulumi.Input[_builtins.str]] = None,
            query_text: Optional[pulumi.Input[_builtins.str]] = None,
            run_as: Optional[pulumi.Input[Union['AlertV2RunAsArgs', 'AlertV2RunAsArgsDict']]] = None,
            run_as_user_name: Optional[pulumi.Input[_builtins.str]] = None,
            schedule: Optional[pulumi.Input[Union['AlertV2ScheduleArgs', 'AlertV2ScheduleArgsDict']]] = None,
            update_time: Optional[pulumi.Input[_builtins.str]] = None,
            warehouse_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'AlertV2':
        """
        Get an existing AlertV2 resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] create_time: (string) - The timestamp indicating when the alert was created
        :param pulumi.Input[_builtins.str] custom_description: Custom description for the alert. support mustache template
        :param pulumi.Input[_builtins.str] custom_summary: Custom summary for the alert. support mustache template
        :param pulumi.Input[_builtins.str] display_name: The display name of the alert
        :param pulumi.Input[Union['AlertV2EffectiveRunAsArgs', 'AlertV2EffectiveRunAsArgsDict']] effective_run_as: (AlertV2RunAs) - The actual identity that will be used to execute the alert.
               This is an output-only field that shows the resolved run-as identity after applying
               permissions and defaults
        :param pulumi.Input[_builtins.str] lifecycle_state: (string) - Indicates whether the query is trashed. Possible values are: `ACTIVE`, `DELETED`
        :param pulumi.Input[_builtins.str] owner_user_name: (string) - The owner's username. This field is set to "Unavailable" if the user has been deleted
        :param pulumi.Input[_builtins.str] parent_path: The workspace path of the folder containing the alert. Can only be set on create, and cannot be updated
        :param pulumi.Input[_builtins.str] query_text: Text of the query to be run
        :param pulumi.Input[Union['AlertV2RunAsArgs', 'AlertV2RunAsArgsDict']] run_as: Specifies the identity that will be used to run the alert.
               This field allows you to configure alerts to run as a specific user or service principal.
               - For user identity: Set `user_name` to the email of an active workspace user. Users can only set this to their own email.
               - For service principal: Set `service_principal_name` to the application ID. Requires the `servicePrincipal/user` role.
               If not specified, the alert will run as the request user
        :param pulumi.Input[_builtins.str] run_as_user_name: The run as username or application ID of service principal.
               On Create and Update, this field can be set to application ID of an active service principal. Setting this field requires the servicePrincipal/user role.
               Deprecated: Use `run_as` field instead. This field will be removed in a future release
        :param pulumi.Input[_builtins.str] update_time: (string) - The timestamp indicating when the alert was updated
        :param pulumi.Input[_builtins.str] warehouse_id: ID of the SQL warehouse attached to the alert
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AlertV2State.__new__(_AlertV2State)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["custom_description"] = custom_description
        __props__.__dict__["custom_summary"] = custom_summary
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["effective_run_as"] = effective_run_as
        __props__.__dict__["evaluation"] = evaluation
        __props__.__dict__["lifecycle_state"] = lifecycle_state
        __props__.__dict__["owner_user_name"] = owner_user_name
        __props__.__dict__["parent_path"] = parent_path
        __props__.__dict__["query_text"] = query_text
        __props__.__dict__["run_as"] = run_as
        __props__.__dict__["run_as_user_name"] = run_as_user_name
        __props__.__dict__["schedule"] = schedule
        __props__.__dict__["update_time"] = update_time
        __props__.__dict__["warehouse_id"] = warehouse_id
        return AlertV2(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The timestamp indicating when the alert was created
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter(name="customDescription")
    def custom_description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Custom description for the alert. support mustache template
        """
        return pulumi.get(self, "custom_description")

    @_builtins.property
    @pulumi.getter(name="customSummary")
    def custom_summary(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Custom summary for the alert. support mustache template
        """
        return pulumi.get(self, "custom_summary")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[_builtins.str]:
        """
        The display name of the alert
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="effectiveRunAs")
    def effective_run_as(self) -> pulumi.Output['outputs.AlertV2EffectiveRunAs']:
        """
        (AlertV2RunAs) - The actual identity that will be used to execute the alert.
        This is an output-only field that shows the resolved run-as identity after applying
        permissions and defaults
        """
        return pulumi.get(self, "effective_run_as")

    @_builtins.property
    @pulumi.getter
    def evaluation(self) -> pulumi.Output['outputs.AlertV2Evaluation']:
        return pulumi.get(self, "evaluation")

    @_builtins.property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - Indicates whether the query is trashed. Possible values are: `ACTIVE`, `DELETED`
        """
        return pulumi.get(self, "lifecycle_state")

    @_builtins.property
    @pulumi.getter(name="ownerUserName")
    def owner_user_name(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The owner's username. This field is set to "Unavailable" if the user has been deleted
        """
        return pulumi.get(self, "owner_user_name")

    @_builtins.property
    @pulumi.getter(name="parentPath")
    def parent_path(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The workspace path of the folder containing the alert. Can only be set on create, and cannot be updated
        """
        return pulumi.get(self, "parent_path")

    @_builtins.property
    @pulumi.getter(name="queryText")
    def query_text(self) -> pulumi.Output[_builtins.str]:
        """
        Text of the query to be run
        """
        return pulumi.get(self, "query_text")

    @_builtins.property
    @pulumi.getter(name="runAs")
    def run_as(self) -> pulumi.Output[Optional['outputs.AlertV2RunAs']]:
        """
        Specifies the identity that will be used to run the alert.
        This field allows you to configure alerts to run as a specific user or service principal.
        - For user identity: Set `user_name` to the email of an active workspace user. Users can only set this to their own email.
        - For service principal: Set `service_principal_name` to the application ID. Requires the `servicePrincipal/user` role.
        If not specified, the alert will run as the request user
        """
        return pulumi.get(self, "run_as")

    @_builtins.property
    @pulumi.getter(name="runAsUserName")
    def run_as_user_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The run as username or application ID of service principal.
        On Create and Update, this field can be set to application ID of an active service principal. Setting this field requires the servicePrincipal/user role.
        Deprecated: Use `run_as` field instead. This field will be removed in a future release
        """
        return pulumi.get(self, "run_as_user_name")

    @_builtins.property
    @pulumi.getter
    def schedule(self) -> pulumi.Output['outputs.AlertV2Schedule']:
        return pulumi.get(self, "schedule")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> pulumi.Output[_builtins.str]:
        """
        (string) - The timestamp indicating when the alert was updated
        """
        return pulumi.get(self, "update_time")

    @_builtins.property
    @pulumi.getter(name="warehouseId")
    def warehouse_id(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the SQL warehouse attached to the alert
        """
        return pulumi.get(self, "warehouse_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetEntityTagAssignmentsResult',
    'AwaitableGetEntityTagAssignmentsResult',
    'get_entity_tag_assignments',
    'get_entity_tag_assignments_output',
]

@pulumi.output_type
class GetEntityTagAssignmentsResult:
    """
    A collection of values returned by getEntityTagAssignments.
    """
    def __init__(__self__, entity_name=None, entity_type=None, id=None, max_results=None, tag_assignments=None):
        if entity_name and not isinstance(entity_name, str):
            raise TypeError("Expected argument 'entity_name' to be a str")
        pulumi.set(__self__, "entity_name", entity_name)
        if entity_type and not isinstance(entity_type, str):
            raise TypeError("Expected argument 'entity_type' to be a str")
        pulumi.set(__self__, "entity_type", entity_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if max_results and not isinstance(max_results, int):
            raise TypeError("Expected argument 'max_results' to be a int")
        pulumi.set(__self__, "max_results", max_results)
        if tag_assignments and not isinstance(tag_assignments, list):
            raise TypeError("Expected argument 'tag_assignments' to be a list")
        pulumi.set(__self__, "tag_assignments", tag_assignments)

    @_builtins.property
    @pulumi.getter(name="entityName")
    def entity_name(self) -> _builtins.str:
        """
        (string) - The fully qualified name of the entity to which the tag is assigned
        """
        return pulumi.get(self, "entity_name")

    @_builtins.property
    @pulumi.getter(name="entityType")
    def entity_type(self) -> _builtins.str:
        """
        (string) - The type of the entity to which the tag is assigned. Allowed values are: catalogs, schemas, tables, columns, volumes
        """
        return pulumi.get(self, "entity_type")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="maxResults")
    def max_results(self) -> Optional[_builtins.int]:
        return pulumi.get(self, "max_results")

    @_builtins.property
    @pulumi.getter(name="tagAssignments")
    def tag_assignments(self) -> Sequence['outputs.GetEntityTagAssignmentsTagAssignmentResult']:
        return pulumi.get(self, "tag_assignments")


class AwaitableGetEntityTagAssignmentsResult(GetEntityTagAssignmentsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEntityTagAssignmentsResult(
            entity_name=self.entity_name,
            entity_type=self.entity_type,
            id=self.id,
            max_results=self.max_results,
            tag_assignments=self.tag_assignments)


def get_entity_tag_assignments(entity_name: Optional[_builtins.str] = None,
                               entity_type: Optional[_builtins.str] = None,
                               max_results: Optional[_builtins.int] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEntityTagAssignmentsResult:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source allows you to retrieve tag assignments that have been applied to a particular entity in Unity Catalog.

    ## Example Usage

    ### Get all tag assignments for a catalog

    ```python
    import pulumi
    import pulumi_databricks as databricks

    catalog_tags = databricks.get_entity_tag_assignments(entity_type="catalogs",
        entity_name="production_catalog")
    schema_tags = databricks.get_entity_tag_assignments(entity_type="schemas",
        entity_name="production_catalog.sales_data")
    table_tags = databricks.get_entity_tag_assignments(entity_type="tables",
        entity_name="production_catalog.sales_data.customer_orders")
    column_tags = databricks.get_entity_tag_assignments(entity_type="columns",
        entity_name="production_catalog.customer_data.users.email_address")
    volume_tags = databricks.get_entity_tag_assignments(entity_type="volumes",
        entity_name="production_catalog.raw_data.landing_zone")
    ```


    :param _builtins.str entity_name: The fully qualified name of the entity to which the tag is assigned
    :param _builtins.str entity_type: The type of the entity to which the tag is assigned. Allowed values are: catalogs, schemas, tables, columns, volumes
    :param _builtins.int max_results: Optional. Maximum number of tag assignments to return in a single page
    """
    __args__ = dict()
    __args__['entityName'] = entity_name
    __args__['entityType'] = entity_type
    __args__['maxResults'] = max_results
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getEntityTagAssignments:getEntityTagAssignments', __args__, opts=opts, typ=GetEntityTagAssignmentsResult).value

    return AwaitableGetEntityTagAssignmentsResult(
        entity_name=pulumi.get(__ret__, 'entity_name'),
        entity_type=pulumi.get(__ret__, 'entity_type'),
        id=pulumi.get(__ret__, 'id'),
        max_results=pulumi.get(__ret__, 'max_results'),
        tag_assignments=pulumi.get(__ret__, 'tag_assignments'))
def get_entity_tag_assignments_output(entity_name: Optional[pulumi.Input[_builtins.str]] = None,
                                      entity_type: Optional[pulumi.Input[_builtins.str]] = None,
                                      max_results: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEntityTagAssignmentsResult]:
    """
    [![Public Preview](https://img.shields.io/badge/Release_Stage-Public_Preview-yellowgreen)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source allows you to retrieve tag assignments that have been applied to a particular entity in Unity Catalog.

    ## Example Usage

    ### Get all tag assignments for a catalog

    ```python
    import pulumi
    import pulumi_databricks as databricks

    catalog_tags = databricks.get_entity_tag_assignments(entity_type="catalogs",
        entity_name="production_catalog")
    schema_tags = databricks.get_entity_tag_assignments(entity_type="schemas",
        entity_name="production_catalog.sales_data")
    table_tags = databricks.get_entity_tag_assignments(entity_type="tables",
        entity_name="production_catalog.sales_data.customer_orders")
    column_tags = databricks.get_entity_tag_assignments(entity_type="columns",
        entity_name="production_catalog.customer_data.users.email_address")
    volume_tags = databricks.get_entity_tag_assignments(entity_type="volumes",
        entity_name="production_catalog.raw_data.landing_zone")
    ```


    :param _builtins.str entity_name: The fully qualified name of the entity to which the tag is assigned
    :param _builtins.str entity_type: The type of the entity to which the tag is assigned. Allowed values are: catalogs, schemas, tables, columns, volumes
    :param _builtins.int max_results: Optional. Maximum number of tag assignments to return in a single page
    """
    __args__ = dict()
    __args__['entityName'] = entity_name
    __args__['entityType'] = entity_type
    __args__['maxResults'] = max_results
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getEntityTagAssignments:getEntityTagAssignments', __args__, opts=opts, typ=GetEntityTagAssignmentsResult)
    return __ret__.apply(lambda __response__: GetEntityTagAssignmentsResult(
        entity_name=pulumi.get(__response__, 'entity_name'),
        entity_type=pulumi.get(__response__, 'entity_type'),
        id=pulumi.get(__response__, 'id'),
        max_results=pulumi.get(__response__, 'max_results'),
        tag_assignments=pulumi.get(__response__, 'tag_assignments')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetServicePrincipalFederationPolicyResult',
    'AwaitableGetServicePrincipalFederationPolicyResult',
    'get_service_principal_federation_policy',
    'get_service_principal_federation_policy_output',
]

@pulumi.output_type
class GetServicePrincipalFederationPolicyResult:
    """
    A collection of values returned by getServicePrincipalFederationPolicy.
    """
    def __init__(__self__, create_time=None, description=None, id=None, name=None, oidc_policy=None, policy_id=None, service_principal_id=None, uid=None, update_time=None):
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if oidc_policy and not isinstance(oidc_policy, dict):
            raise TypeError("Expected argument 'oidc_policy' to be a dict")
        pulumi.set(__self__, "oidc_policy", oidc_policy)
        if policy_id and not isinstance(policy_id, str):
            raise TypeError("Expected argument 'policy_id' to be a str")
        pulumi.set(__self__, "policy_id", policy_id)
        if service_principal_id and not isinstance(service_principal_id, int):
            raise TypeError("Expected argument 'service_principal_id' to be a int")
        pulumi.set(__self__, "service_principal_id", service_principal_id)
        if uid and not isinstance(uid, str):
            raise TypeError("Expected argument 'uid' to be a str")
        pulumi.set(__self__, "uid", uid)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)

    @_builtins.property
    @pulumi.getter(name="createTime")
    def create_time(self) -> _builtins.str:
        """
        (string) - Creation time of the federation policy
        """
        return pulumi.get(self, "create_time")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        (string) - Description of the federation policy
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        (string) - Resource name for the federation policy. Example values include
        `accounts/<account-id>/federationPolicies/my-federation-policy` for Account Federation Policies, and
        `accounts/<account-id>/servicePrincipals/<service-principal-id>/federationPolicies/my-federation-policy`
        for Service Principal Federation Policies. Typically an output parameter, which does not need to be
        specified in create or update requests. If specified in a request, must match the value in the
        request URL
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="oidcPolicy")
    def oidc_policy(self) -> 'outputs.GetServicePrincipalFederationPolicyOidcPolicyResult':
        """
        (OidcFederationPolicy)
        """
        return pulumi.get(self, "oidc_policy")

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> _builtins.str:
        """
        (string) - The ID of the federation policy. Output only
        """
        return pulumi.get(self, "policy_id")

    @_builtins.property
    @pulumi.getter(name="servicePrincipalId")
    def service_principal_id(self) -> _builtins.int:
        """
        (integer) - The service principal ID that this federation policy applies to. Output only. Only set for service principal federation policies
        """
        return pulumi.get(self, "service_principal_id")

    @_builtins.property
    @pulumi.getter
    def uid(self) -> _builtins.str:
        """
        (string) - Unique, immutable id of the federation policy
        """
        return pulumi.get(self, "uid")

    @_builtins.property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> _builtins.str:
        """
        (string) - Last update time of the federation policy
        """
        return pulumi.get(self, "update_time")


class AwaitableGetServicePrincipalFederationPolicyResult(GetServicePrincipalFederationPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServicePrincipalFederationPolicyResult(
            create_time=self.create_time,
            description=self.description,
            id=self.id,
            name=self.name,
            oidc_policy=self.oidc_policy,
            policy_id=self.policy_id,
            service_principal_id=self.service_principal_id,
            uid=self.uid,
            update_time=self.update_time)


def get_service_principal_federation_policy(policy_id: Optional[_builtins.str] = None,
                                            service_principal_id: Optional[_builtins.int] = None,
                                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServicePrincipalFederationPolicyResult:
    """
    [![GA](https://img.shields.io/badge/Release_Stage-GA-green)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single service principal federation policy.

    > **Note** This data source can only be used with an account-level provider!

    ## Example Usage

    Referring to a service principal federation policy by id:


    :param _builtins.str policy_id: The ID of the federation policy. Output only
    :param _builtins.int service_principal_id: The service principal ID that this federation policy applies to. Output only. Only set for service principal federation policies
    """
    __args__ = dict()
    __args__['policyId'] = policy_id
    __args__['servicePrincipalId'] = service_principal_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('databricks:index/getServicePrincipalFederationPolicy:getServicePrincipalFederationPolicy', __args__, opts=opts, typ=GetServicePrincipalFederationPolicyResult).value

    return AwaitableGetServicePrincipalFederationPolicyResult(
        create_time=pulumi.get(__ret__, 'create_time'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        oidc_policy=pulumi.get(__ret__, 'oidc_policy'),
        policy_id=pulumi.get(__ret__, 'policy_id'),
        service_principal_id=pulumi.get(__ret__, 'service_principal_id'),
        uid=pulumi.get(__ret__, 'uid'),
        update_time=pulumi.get(__ret__, 'update_time'))
def get_service_principal_federation_policy_output(policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                                                   service_principal_id: Optional[pulumi.Input[_builtins.int]] = None,
                                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServicePrincipalFederationPolicyResult]:
    """
    [![GA](https://img.shields.io/badge/Release_Stage-GA-green)](https://docs.databricks.com/aws/en/release-notes/release-types)

    This data source can be used to get a single service principal federation policy.

    > **Note** This data source can only be used with an account-level provider!

    ## Example Usage

    Referring to a service principal federation policy by id:


    :param _builtins.str policy_id: The ID of the federation policy. Output only
    :param _builtins.int service_principal_id: The service principal ID that this federation policy applies to. Output only. Only set for service principal federation policies
    """
    __args__ = dict()
    __args__['policyId'] = policy_id
    __args__['servicePrincipalId'] = service_principal_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('databricks:index/getServicePrincipalFederationPolicy:getServicePrincipalFederationPolicy', __args__, opts=opts, typ=GetServicePrincipalFederationPolicyResult)
    return __ret__.apply(lambda __response__: GetServicePrincipalFederationPolicyResult(
        create_time=pulumi.get(__response__, 'create_time'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        oidc_policy=pulumi.get(__response__, 'oidc_policy'),
        policy_id=pulumi.get(__response__, 'policy_id'),
        service_principal_id=pulumi.get(__response__, 'service_principal_id'),
        uid=pulumi.get(__response__, 'uid'),
        update_time=pulumi.get(__response__, 'update_time')))
